---
name: Feature Request
about: Suggest an idea for hyppo
label: enhancement

---

**Is your feature request related to a problem? Please describe.**


**Describe the solution you'd like**


**Describe alternatives you've considered**


**Additional context (e.g. screenshots)**
